# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.5.2](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.5.1...aoe2rec-v0.5.2) - 2025-12-14

### Other

- Make actions and header public

## [0.5.1](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.5.0...aoe2rec-v0.5.1) - 2025-12-13

### Other

- Implement the Research action

## [0.5.0](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.4.0...aoe2rec-v0.5.0) - 2025-12-12

### Other

- Implement Order action

## [0.4.0](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.3.0...aoe2rec-v0.4.0) - 2025-12-12

### Other

- Fix Interact action and alignment issues

## [0.3.0](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.2.5...aoe2rec-v0.3.0) - 2025-12-12

### Other

- Fix linting errors and update depedencies
- Implement action for DeQueue
- Implement Move and Chapter actions, add Action 104
- Rename name2 to censored_name

## [0.2.5](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.2.4...aoe2rec-v0.2.5) - 2025-08-15

### Fixed

- Treat new field as a count

## [0.2.4](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.2.3...aoe2rec-v0.2.4) - 2025-08-14

### Other

- Split empty players in separate field

## [0.2.3](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.2.2...aoe2rec-v0.2.3) - 2025-08-13

### Other

- Fix js library errors

## [0.2.2](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.2.1...aoe2rec-v0.2.2) - 2025-08-13

### Other

- Add missing files
- Add first part of changes to be compatible with savegames >= 66
- Add more fields to the Initial Player structure
- Improve parsing of minor version

## [0.2.1](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.2.0...aoe2rec-v0.2.1) - 2025-04-11

### Added

- Add support for newer aoe2record version 64.19661

## [0.2.0](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.1.6...aoe2rec-v0.2.0) - 2025-03-30

### Fixed

- Correctly parse recs with saved Chapters

## [0.1.6](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.1.5...aoe2rec-v0.1.6) - 2025-02-23

### Fixed

- Add missing unknown GameCommands

## [0.1.5](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.1.4...aoe2rec-v0.1.5) - 2025-02-22

### Added

- Provide a Summary for savegames with essential information

## [0.1.4](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.1.3...aoe2rec-v0.1.4) - 2025-02-05

### Other

- Make structs debuggable

## [0.1.3](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.1.2...aoe2rec-v0.1.3) - 2025-01-13

### Added

- Add player_id to actions

## [0.1.2](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.1.1...aoe2rec-v0.1.2) - 2025-01-12

### Other

- update Cargo.lock dependencies

## [0.1.1](https://github.com/aoe2ct/aoe2rec/compare/aoe2rec-v0.1.0...aoe2rec-v0.1.1) - 2025-01-12

### Other

- Add other missing descriptions, do not publish API crate
